==> v8.3.zip: ru_twords_ru_tw/bible/other/generation.md <==
# родословие

## Определение:

Поколение — обычно это люди, близкие по возрасту, живущие в одно время.

* Поколением может называться определённый исторический промежуток. Например, в Библии “поколением” обычно назывался период длительностью в сорок лет.
* Родители и дети являются представителями разных поколений.
* В Писании это слово может употребляться не только в прямом, но и в переносном значении, например, когда речь идёт о людях со схожими характеристиками.

## Варианты перевода

* Выражение “это поколение” или “люди этого поколения” может быть переведено как “ныне живущие люди” или “вы”.
* Словосочетание “это развращенное поколение” можно перевести как “злые люди, живущие в настоящее время”.
* Выражение “из поколения в поколение” или “от одного поколения к другому” можно перевести как “люди, живущие в настоящее время, а также их дети и внуки”, “ныне живущий народ и их потомки”, “те, кто живёт сейчас и будет жить в будущем”.
* Фразу “Грядущее поколение будет Ему служить и расскажет следующему о Яхве” (см. Псалом 77:6) можно перефразировать так: “Многие люди в будущем будут служить Яхве и расскажут о Нём своим детям и внукам”.

(См. также: [потомок](../other/descendant.md), [зло](../kt/evil.md), [предок](../other/father.md))

## Ссылки на библейский текст:

* [Деян. 15:19-21](rc://*/tn/help/act/15/19)
* [Исх. 3:13-15](rc://*/tn/help/exo/03/13)
* [Быт. 15:16](rc://*/tn/help/gen/15/16)
* [Быт. 17:7](rc://*/tn/help/gen/17/07)
* [Мк. 8:12](rc://*/tn/help/mrk/08/12)
* [Мф. 11:16](rc://*/tn/help/mat/11/16)
* [Мф. 23:34-36](rc://*/tn/help/mat/23/34)
* [Мф. 24:34](rc://*/tn/help/mat/24/34)

## Данные о слове:

* номера Стронга: H1755, H1859, H8435, G1074

==> v9.2.zip: ru_twords_ru_tw/bible/other/generation.md <==
# родословие

## Определение:

Поколение — обычно это люди, близкие по возрасту, живущие в одно время. 

* Поколением может называться определённый исторический промежуток. Например, в Библии “поколением” обычно назывался период длительностью в сорок лет. 
* Родители и дети являются представителями разных поколений. 
* В Писании это слово может употребляться не только в прямом, но и в переносном значении, например, когда речь идёт о людях со схожими характеристиками.  

## Варианты перевода

* Выражение “это поколение” или “люди этого поколения” может быть переведено как “ныне живущие люди” или “вы”. 
* Словосочетание “это развращенное поколение” можно перевести как “злые люди, живущие в настоящее время”. 
* Выражение “из поколения в поколение” или “от одного поколения к другому” можно перевести как “люди, живущие в настоящее время, а также их дети и внуки”, “ныне живущий народ и их потомки”, “те, кто живёт сейчас и будет жить в будущем”. 
* Фразу “Грядущее поколение будет Ему служить и расскажет следующему о Яхве” (см. Псалом 77:6) можно перефразировать так: “Многие люди в будущем будут служить Яхве и расскажут о Нём своим детям и внукам”. 

(См. также: [потомок](../other/descendant.md), [зло](../kt/evil.md), [предок](../other/father.md))

## Ссылки на библейский текст:

* [Деян. 15:19-21](rc://ru/tn/help/act/15/19)
* [Исх. 3:13-15](rc://ru/tn/help/exo/03/13)
* [Быт. 15:16](rc://ru/tn/help/gen/15/16)
* [Быт. 17:7](rc://ru/tn/help/gen/17/07)
* [Мк. 8:12](rc://ru/tn/help/mrk/08/12)
* [Мф. 11:16](rc://ru/tn/help/mat/11/16)
* [Мф. 23:34-36](rc://ru/tn/help/mat/23/34)
* [Мф. 24:34](rc://ru/tn/help/mat/24/34)

## Данные о слове:

* номера Стронга: H1755, H1859, H8435, G1074
